@@ -1,12 +1,12 @@
 ;;; parsebib.el --- A library for parsing bib files  -*- lexical-binding: t -*-
 
-;; Copyright (c) 2014-2024 Joost Kremers
+;; Copyright (c) 2014-2025 Joost Kremers
 ;; All rights reserved.
 
 ;; Author: Joost Kremers <joostkremers@fastmail.fm>
 ;; Maintainer: Joost Kremers <joostkremers@fastmail.fm>
 ;; Created: 2014
-;; Version: 6.6
+;; Version: 6.7
 ;; Keywords: text bibtex
 ;; URL: https://github.com/joostkremers/parsebib
 ;; Package-Requires: ((emacs "25.1"))
@@ -297,7 +297,7 @@ sequences)."
        ((eq (char-after) close)
         (unless (eq (char-before) esc)
           (setq n-braces (1- n-braces)))))
-      (ignore-error 'end-of-buffer (forward-char 1)))
+      (ignore-error end-of-buffer (forward-char 1)))
     (if (= n-braces 0)
         (buffer-substring-no-properties beg (point))
       (signal 'parsebib-error (list beg
@@ -373,6 +373,10 @@ should be read literally."
   "Parse text in double quotes."
   (parsebib--string ?\" ?\\))
 
+(defun parsebib--key ()
+  "Parse a BibTeX key."
+  (parsebib--symbol parsebib--bibtex-key-regexp))
+
 (defun parsebib--identifier ()
   "Parse a BibTeX identifier."
   (parsebib--symbol parsebib--bibtex-identifier))
@@ -419,7 +423,7 @@ A set of assignments makes up the body of an entry."
       ;; There may be a comma after the final field of an entry. If that
       ;; happens, reading another assignment will fail, so we capture the
       ;; error here.
-      (ignore-error 'parsebib-error
+      (ignore-error parsebib-error
         (push (parsebib--assignment) fields)))
     fields))
 
@@ -462,7 +466,7 @@ Return the entry as an alist of <field . value> pairs, where
   (if-let* ((_ (parsebib--char '(?@)))
             (type (parsebib--identifier))
             (open (parsebib--char '(?\{ ?\( )))
-            (key (parsebib--identifier))
+            (key (parsebib--key))
             (_ (parsebib--char '(?,)))
             (fields (parsebib--fields))
             (_ (parsebib--char (alist-get open '((?\{ ?\}) (?\( ?\)))))))
